@@ -23,7 +23,7 @@ main (int argc, char **argv)
 	GError *error = NULL;
 	int i;
 
-	g_type_init ();
+	arv_g_type_init ();
 
 	context = g_option_context_new (NULL);
 	g_option_context_add_main_entries (context, arv_option_entries, NULL);
