@@ -12,7 +12,6 @@ static const ExpressionTestData expression_test_data[] = {
 	{"/evaluator/addition", 			"10+2", 		12, 	12.0},
 	{"/evaluator/parentheses",			"(24+2)*2",		52, 	52.0},
 	{"/evaluator/precedence",			"24+2*8",		40, 	40.0},
-	{"/evaluator/sin",				"sin(PI/2.0)",		1,	1.0},
 	{"/evaluator/ternary-true",			"1=1?1:0",		1,	1.0},
 	{"/evaluator/ternary-false",			"1=0?1:0",		0,	0.0},
 	{"/evaluator/greater-true",			"2>1",			1,	1.0},
@@ -35,8 +34,6 @@ static const ExpressionTestData expression_test_data[] = {
 	{"/evaluator/not-equal-false",			"1<>1",			0,	0.0},
 	{"/evaluator/equal-true",			"1=1",			1,	1.0},
 	{"/evaluator/equal-false",			"1=2",			0,	0.0},
-	{"/evaluator/greater-true",			"2>1",			1,	1.0},
-	{"/evaluator/greater-false",			"1>1",			0,	0.0},
 	{"/evaluator/less-true",			"1<2",			1,	1.0},
 	{"/evaluator/less-false",			"1<1",			0,	0.0},
 	{"/evaluator/greater-or-equal-true",		"2>=2",			1,	1.0},
